@@ -19,9 +19,9 @@
  *
  * Automatic wallpaper changer
  *
- * @date December 7, 2019
+ * @date December 9, 2019
  *
- * @version 1.3.3
+ * @version 1.3.4
  * 
  * @author Michał Bąbik <michalb1981@o2.pl>
  */
@@ -40,7 +40,7 @@
 #include "errs.h"
 #include "miscfun.h"
 #define APP_NAME "Wall Changer"
-#define APP_VER  "1.3.3"
+#define APP_VER  "1.3.4"
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Structore to pass widgets and settings to callback
@@ -399,7 +399,7 @@ get_wallpaper_list (GtkWidget *gw_view,
     GSList     *gsl_iinfo1 = NULL; /* List of ImageInfo data */
     const char *s_val      = NULL; /* Full file path */
     char       *s_name     = NULL; /* Unique name for background file */
-    size_t      ui_no      = 0;    /* Number to append to name */
+    size_t      ul_no      = 0;    /* Number to append to name */
 
     /* get ImageInfo list of TreeView files */
     gsl_iinfo1 = treeview_get_data (gw_view);
@@ -417,7 +417,7 @@ get_wallpaper_list (GtkWidget *gw_view,
 
         s_val = ii_info->s_full_path;
         s_name = string_name_with_number (get_setting_name (SETTING_WALL_ARRAY),
-                                          ui_no++);
+                                          ul_no++);
 
         st_sett = setting_new_string (s_val, s_name);
 
@@ -1253,7 +1253,7 @@ main (int    argc,
     int             status;
     DialogData      dd_data;
 
-    app = gtk_application_new ("pl.pomorze.init6.wallchanger",
+    app = gtk_application_new ("org.nongnu.WallChanger",
                                G_APPLICATION_FLAGS_NONE);
 
     g_signal_connect (app, "activate", G_CALLBACK (activate), &dd_data);
